pub fn render(page: &Page, opts: &RenderOptions) -> PixmapExpand description
Export a page into a raster image.
This renders the page at the given number of pixels per point and returns
the resulting tiny-skia pixel buffer.
pub fn render(page: &Page, opts: &RenderOptions) -> PixmapExport a page into a raster image.
This renders the page at the given number of pixels per point and returns
the resulting tiny-skia pixel buffer.