pub fn render_merged(
document: &PagedDocument,
opts: &RenderOptions,
gap: Abs,
fill: Option<Color>,
) -> PixmapExpand description
Export a document with potentially multiple pages into a single raster image.
pub fn render_merged(
document: &PagedDocument,
opts: &RenderOptions,
gap: Abs,
fill: Option<Color>,
) -> PixmapExport a document with potentially multiple pages into a single raster image.